GeoFeature class
Constructors
-
GeoFeature({required GeoGeometry geometry, required Map<
String, dynamic> properties}) -
GeoFeature.fromJson(Map<
String, dynamic> json) -
factory
Properties
- geometry ↔ GeoGeometry
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
properties
↔ Map<
String, dynamic> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parseGeometry(
Map< String, dynamic> json) → GeoGeometry