GeoJSONHandler class

Constructors

GeoJSONHandler()

Properties

features List<GeoFeature>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addFeature(GeoFeature feature) → void
exportToGeoJSON() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseGeoJSONFile(String filePath) Future<void>
parseGeoJSONString(String geoJsonString) → void
removeFeature(GeoFeature feature) → void
saveToGeoJSONFile(String filePath) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited