GeoMultiLineString class
- Inheritance
-
- Object
- GeoGeometry
- GeoMultiLineString
Constructors
-
GeoMultiLineString(List<
List< lineStrings)LatLng> >
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lineStrings
→ List<
List< LatLng> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
toWKT(
) → String -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited